==> flutter_helper-0.0.15.tar.gz: lib/src/Services/AuthService.dart <==
import 'dart:async';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:rxdart/rxdart.dart';

class AuthService {
  final FirebaseAuth _auth = FirebaseAuth.instance;

  bool isSignedIn() {
    return _auth.currentUser != null;
  }

  bool getIsEmailVerified() {
    return _auth.currentUser?.emailVerified ?? true;
  }

  User? getCurrentUser() {
    return _auth.currentUser;
  }

  String uid() {
    return FirebaseAuth.instance.currentUser?.uid ?? "_";
  }

  Future<void> resetPassword(String email) async {
    await _auth.sendPasswordResetEmail(email: email);
  }

  Future<void> signIn(String email, String password) async {
    await _auth.signInWithEmailAndPassword(
        email: email, password: password);
  }

  Future<User?> signUp(String email, String password, {
    String firstName = "",
    String lastName = ""
  }) async {
    final User? user = (await _auth.createUserWithEmailAndPassword(
            email: email, password: password))
        .user;

    await user?.updateDisplayName(firstName + " " + lastName);

    await user?.reload();

    return FirebaseAuth.instance.currentUser;
  }

  Future<void> sendEmailVerification(User user, ActionCodeSettings actionCodeSettings) async {
    if (!user.emailVerified) {
      user.sendEmailVerification(actionCodeSettings);
    }
  }

  Future<void> signOut() async {
    await _auth.signOut();
  }

  Future<void> deleteUser(String password) async {
    final User user = _auth.currentUser!;

    await user.reauthenticateWithCredential(
        EmailAuthProvider.credential(email: user.email!, password: password));

    await user.delete();
  }

  Future<void> updateEmail(String email, String password) async {
    final User user = _auth.currentUser!;

    await user.reauthenticateWithCredential(
        EmailAuthProvider.credential(email: user.email!, password: password));

    await user.updateEmail(email);
  }

  Future<void> updatePassword(String newPassword, String password) async {
    final User user = _auth.currentUser!;

    await user.reauthenticateWithCredential(
        EmailAuthProvider.credential(email: user.email!, password: password));

    await user.updatePassword(newPassword);
  }


  Stream<String> onIdChanged() async* {
    await for (final user in FirebaseAuth.instance.authStateChanges()) {
      yield user?.uid ?? "";
    }
  }

  Stream<User?> onAuthChanged() {
    return onAuthChangedSubject;
  }

  final BehaviorSubject<User?> onAuthChangedSubject = BehaviorSubject<User?>();

  AuthService() {
    FirebaseAuth.instance.authStateChanges().listen((event) {
      onAuthChangedSubject.add(event);
    });
  }
}

==> flutter_helper-0.0.16.tar.gz: lib/src/Services/AuthService.dart <==
import 'dart:async';
import 'dart:math';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:rxdart/rxdart.dart';

class AuthService {
  final FirebaseAuth _auth = FirebaseAuth.instance;

  bool isSignedIn() {
    return _auth.currentUser != null;
  }

  bool getIsEmailVerified() {
    return _auth.currentUser?.emailVerified ?? true;
  }

  User? getCurrentUser() {
    return _auth.currentUser;
  }

  String getUid() {
    return _auth.currentUser?.uid ?? "_";
  }

  Future<void> resetPassword(String email) async {
    await _auth.sendPasswordResetEmail(email: email);
  }

  Future<void> signIn(String email, String password) async {
    await _auth.signInWithEmailAndPassword(
        email: email, password: password);
  }

  Future<User?> signUp(String email, String password) async {
    final User? user = (await _auth.createUserWithEmailAndPassword(
            email: email, password: password))
        .user;

    await user?.reload();

    return FirebaseAuth.instance.currentUser;
  }

  Future<void> sendEmailVerification(User user, ActionCodeSettings actionCodeSettings) async {
    if (!user.emailVerified) {
      user.sendEmailVerification(actionCodeSettings);
    }
  }

  Future<void> signOut() async {
    await _auth.signOut();
  }

  Future<void> deleteUser(String password) async {
    final User user = _auth.currentUser!;

    await user.reauthenticateWithCredential(
        EmailAuthProvider.credential(email: user.email!, password: password));

    await user.delete();
  }

  Future<void> updateEmail(String email, String password) async {
    final User user = _auth.currentUser!;

    await user.reauthenticateWithCredential(
        EmailAuthProvider.credential(email: user.email!, password: password));

    await user.updateEmail(email);
  }

  Future<void> updatePassword(String newPassword, String password) async {
    final User user = _auth.currentUser!;

    await user.reauthenticateWithCredential(
        EmailAuthProvider.credential(email: user.email!, password: password));

    await user.updatePassword(newPassword);
  }


  Stream<String> onIdChanged() async* {
    await for (final user in FirebaseAuth.instance.authStateChanges()) {
      yield user?.uid ?? "";
    }
  }

  Stream<User?> onAuthChanged() {
    return onAuthChangedSubject;
  }

  final BehaviorSubject<User?> onAuthChangedSubject = BehaviorSubject<User?>();

  AuthService() {
    FirebaseAuth.instance.authStateChanges().listen((event) {
      onAuthChangedSubject.add(event);
    });
  }

  static Future<UserCredential> getGeneratedUser()async {
    final email = "${Random().nextInt(1000000)}@gmail.com";

    final password = "Test123";

    UserCredential user;

    user = await FirebaseAuth.instance.createUserWithEmailAndPassword(email: email, password: password);

    return user;
  }
}
